Date and Time
~~~~~~~~~~~~~

We format date and time in accordance with ISO 8601, that is: YYYY-MM-DD and
HH:MM:SS (24-hour clock).

For more information, see: https://xkcd.com/1179/

Unless otherwise noted, we display local date and time.
Internally, we store and process date and time as UTC.


.. rubric:: TIMESPAN

Some options accept a TIMESPAN parameter, which can be given as a number of
years (e.g. ``2y``), months (e.g. ``12m``), weeks (e.g. ``2w``),
days (e.g. ``7d``), hours (e.g. ``8H``), minutes (e.g. ``30M``),
or seconds (e.g. ``150S``).
